#แพ็กเกจนี้เป็นแพ็กเกจ python ที่โชว์ข้อมูลเกี่ยวกับ Mon THJP Link:
https://www.youtube.com/watch?v=JsfIcV_4eik

PyPi: https://pypi.org/project/THJPpython/

สวัสดี แพ็คนี้คือแพ็คเกจที่แสดงข้อมูลเกี่ยวกับ Mon THJP ### วิธีติดตั้ง

เปิด CMD / Terminal

.. code:: python

   pip install THJPpython

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

.. code:: python

   from THJPpython import pyamon

   mon = pyamon() #ประกาศชื่อ
   mon.show_name() #โชว์ชื่อ
   mon.show_music() #โชว์ลิงค์เพลง
   mon.about() #เกี่ยวกับฉัน
   mon.show_art() ascii #โชว์ภาพ

พัฒนาโดย: amonTHJP https://github.com/amonTHJP

YouTube: https://www.youtube.com
